@@ -1,19 +1,8 @@
 /*
- * Copyright 2007-2009 by Stefan Böhmann <kde@hilefoks.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2007-2009 Stefan Böhmann <kde@hilefoks.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "tealistmodel.h"
 #include "tea.h"
@@ -29,7 +18,7 @@ TeaListModel::TeaListModel(const QList<Tea> &tealist, QObject *parent)
 
 QModelIndex TeaListModel::index(int row, int column, const QModelIndex &parent) const
 {
-    Q_UNUSED( parent );
+    Q_UNUSED( parent )
 
     return createIndex(row, column);
 }
@@ -47,7 +36,7 @@ int TeaListModel::rowCount(const QModelIndex &parent) const
 
 int TeaListModel::columnCount(const QModelIndex &parent) const
 {
-    Q_UNUSED( parent );
+    Q_UNUSED( parent )
 
     return 2;
 }
@@ -96,7 +85,7 @@ bool TeaListModel::setData(const QModelIndex &index, const QVariant &value, int
         } else if( index.column() == 1 ) {
             m_tealist[ index.row() ].setTime( value.toUInt() );
         }
-        emit dataChanged( index, index );
+        Q_EMIT dataChanged( index, index );
         return true;
     }
 
@@ -117,7 +106,7 @@ QVariant TeaListModel::headerData(int section, Qt::Orientation orientation, int
 
 bool TeaListModel::insertRows(int row, int count, const QModelIndex &parent)
 {
-    Q_UNUSED( parent );
+    Q_UNUSED( parent )
     beginInsertRows( QModelIndex(), row, row+count-1 );
 
     for(int i = 0; i < count; ++i) {
@@ -131,7 +120,7 @@ bool TeaListModel::insertRows(int row, int count, const QModelIndex &parent)
 
 bool TeaListModel::removeRows(int row, int count, const QModelIndex &parent)
 {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
     if( row-count > m_tealist.size() ) {
         return false;
     }
